# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from team_member_server_sdk.models.wrapped_response_list_team_member_response import WrappedResponseListTeamMemberResponse  # noqa: E501

class TestWrappedResponseListTeamMemberResponse(unittest.TestCase):
    """WrappedResponseListTeamMemberResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseListTeamMemberResponse:
        """Test WrappedResponseListTeamMemberResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseListTeamMemberResponse`
        """
        model = WrappedResponseListTeamMemberResponse()  # noqa: E501
        if include_optional:
            return WrappedResponseListTeamMemberResponse(
                done = True,
                result = [
                    team_member_server_sdk.models.team_member_response.TeamMemberResponse(
                        id = 56, 
                        portal_id = 56, 
                        team_member_role_id = 56, 
                        invited_email = '', 
                        invited_code = '', 
                        invited_at = 56, 
                        last_email_sent_at = 56, 
                        activated_at = 56, 
                        enabled_at = 56, 
                        portal_member = null, )
                    ]
            )
        else:
            return WrappedResponseListTeamMemberResponse(
                result = [
                    team_member_server_sdk.models.team_member_response.TeamMemberResponse(
                        id = 56, 
                        portal_id = 56, 
                        team_member_role_id = 56, 
                        invited_email = '', 
                        invited_code = '', 
                        invited_at = 56, 
                        last_email_sent_at = 56, 
                        activated_at = 56, 
                        enabled_at = 56, 
                        portal_member = null, )
                    ],
        )
        """

    def testWrappedResponseListTeamMemberResponse(self):
        """Test WrappedResponseListTeamMemberResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
