# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from team_member_server_sdk.api.server_requests_api import ServerRequestsApi  # noqa: E501


class TestServerRequestsApi(unittest.IsolatedAsyncioTestCase):
    """ServerRequestsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ServerRequestsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_activate_team_member_v1_team_member_activate_post(self) -> None:
        """Test case for activate_team_member_v1_team_member_activate_post

        Activate Team Member  # noqa: E501
        """
        pass

    async def test_get_team_member_access_v1_team_member_access_get_post(self) -> None:
        """Test case for get_team_member_access_v1_team_member_access_get_post

        Get Team Member access  # noqa: E501
        """
        pass

    async def test_get_team_members_v1_team_member_list_post(self) -> None:
        """Test case for get_team_members_v1_team_member_list_post

        Get Team Members  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
